#!/usr/bin/python

import os
import unittest
import logging

from confini import Config

logging.basicConfig(level=logging.DEBUG)
logg = logging.getLogger()

class TestBasic(unittest.TestCase):

    wd = os.path.dirname(__file__)

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def test_parse_two_files(self):
        inidir = os.path.join(self.wd, 'files')
        c = Config(inidir)
        c.process()
        c.require('BERT', 'XYZZY')
        expect = {
            'FOO_BAR': '42',
            'FOO_BAZ': '029a',
            'BAR_FOO': 'oof',
            'XYZZY_BERT': 'ernie',
                }
        self.assertDictEqual(expect, c.store)


    def test_require(self):
        inidir = os.path.join(self.wd, 'files')
        c = Config(inidir)
        c.require('BERT', 'XYZZY')
        self.assertTrue(c.validate())
        c.require('ERNIE', 'XYZZY')
        self.assertFalse(c.validate())
        logg.debug(c)

if __name__ == '__main__':
    unittest.main()



#!/usr/bin/python

import os
import unittest
import logging

from confini import Config
from confini.error import DecryptError

logging.basicConfig(level=logging.DEBUG)
logg = logging.getLogger()

script_dir = os.path.dirname(os.path.realpath(__file__))
gnupg_dir = os.path.join(script_dir, 'gnupg')

class TestBasic(unittest.TestCase):

    wd = os.path.dirname(__file__)

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def test_enc(self):
        inidir = os.path.join(self.wd, 'files/crypt')
        c = Config(inidir, decrypt=True)
        c.process()
        with self.assertRaises(DecryptError):
            c.get('FOO_BAZ')
        os.environ['GNUPGHOME'] = gnupg_dir
        c.get('FOO_BAZ')
    
if __name__ == '__main__':
    unittest.main()



import sys
import logging

from confini import Config

#logging.basicConfig(level=logging.DEBUG)
logg = logging.getLogger()

if __name__ == "__main__":
    if len(sys.argv) < 2:
        sys.stderr.write('usage: config.py <config_dir>')
        sys.exit(1)
    c = Config(sys.argv[1])
    c.process()
    for k in c.store.keys():
        print('{}: {}'.format(k, c.get(k)))
